@@ -1,5 +1,4 @@
 import pandas as pd
-from google.cloud import bigquery
 
 from airflow_commons.glossary import COMMA
 from airflow_commons.logger import LOGGER
@@ -20,6 +19,7 @@ from airflow_commons.utils.bigquery.bigquery_utils import (
     query_information_schema,
     get_table_ref,
     get_primitive_column_list,
+    get_job_config,
 )
 from airflow_commons.utils.bigquery.sql_utils import (
     get_deduplication_source_statement,
@@ -31,7 +31,6 @@ from airflow_commons.utils.file_utils import read_sql
 from airflow_commons.utils.time_utils import get_buffered_timestamp
 
 ARCHIVE_MODES = ["INSERT", "UPSERT"]
-WRITE_DISPOSITIONS = ["WRITE_APPEND", "WRITE_TRUNCATE", "WRITE_EMPTY"]
 DEFAULT_PRIMARY_KEYS = ["id"]
 ARCHIVE_DEFAULT_PRIMARY_KEYS = ["id", "last_updated_at", "processed_at"]
 DEFAULT_TIME_COLUMNS = ["last_updated_at", "processed_at"]
@@ -50,6 +49,7 @@ def deduplicate(
     primary_keys=None,
     time_columns=None,
     allow_partition_pruning: bool = True,
+    job_priority: str = None,
     timeout=DEFAULT_TIMEOUT,
     location=DEFAULT_LOCATION,
 ):
@@ -68,11 +68,14 @@ def deduplicate(
     :param primary_keys: primary key columns of the source and target tables
     :param time_columns: time columns list to order rows
     :param allow_partition_pruning: partition pruning allow parameter, if true prunes target table's partitions to limit query size
+    :param job_priority: priority of bigquery job, it is currently BATCH or INTERACTIVE (default)
     :param timeout: query timeout duration parameter
     :param location: query location parameter
     :return:
     """
     client = connect(service_account_file)
+    job_config = get_job_config(job_priority)
+
     if primary_keys is None:
         primary_keys = DEFAULT_PRIMARY_KEYS
     if time_columns is None:
@@ -136,7 +139,7 @@ def deduplicate(
     )
     return query(
         client=client,
-        job_config=bigquery.QueryJobConfig(),
+        job_config=job_config,
         sql=sql,
         timeout=timeout,
         location=location,
@@ -152,6 +155,7 @@ def upsert(
     source_statement_params: dict = None,
     primary_keys=None,
     additional_merge_conditions: str = None,
+    job_priority: str = None,
     timeout=DEFAULT_TIMEOUT,
     location=DEFAULT_LOCATION,
 ):
@@ -166,11 +170,14 @@ def upsert(
     :param source_statement_params: parameters of source statement
     :param primary_keys: target table's primary key list
     :param additional_merge_conditions: additional user specified merge conditions as string
+    :param job_priority: priority of bigquery job, it is currently BATCH or INTERACTIVE (default)
     :param timeout: query timeout duration in seconds
     :param location: query location parameter
     :return:
     """
     client = connect(service_account_file)
+    job_config = get_job_config(job_priority)
+
     if source_statement_params is None:
         source_statement_params = dict()
     if primary_keys is None:
@@ -190,7 +197,7 @@ def upsert(
     )
     return query(
         client=client,
-        job_config=bigquery.QueryJobConfig(),
+        job_config=job_config,
         sql=sql,
         timeout=timeout,
         location=location,
@@ -206,6 +213,7 @@ def insert(
     source_statement_params: dict = None,
     primary_keys=None,
     additional_merge_conditions: str = None,
+    job_priority: str = None,
     timeout=DEFAULT_TIMEOUT,
     location=DEFAULT_LOCATION,
 ):
@@ -220,11 +228,14 @@ def insert(
     :param source_statement_params: parameters of source statement
     :param additional_merge_conditions: additional user specified merge conditions as string
     :param primary_keys: target table's primary key list
+    :param job_priority: priority of bigquery job, it is currently BATCH or INTERACTIVE (default)
     :param timeout: query timeout duration in seconds
     :param location: query location parameter
     :return:
     """
     client = connect(service_account_file)
+    job_config = get_job_config(job_priority)
+
     if source_statement_params is None:
         source_statement_params = dict()
     if primary_keys is None:
@@ -244,7 +255,7 @@ def insert(
     )
     return query(
         client=client,
-        job_config=bigquery.QueryJobConfig(),
+        job_config=job_config,
         sql=sql,
         timeout=timeout,
         location=location,
@@ -260,9 +271,9 @@ def write_query_results_to_destination(
     destination_table: str,
     write_disposition: str,
     sql_params: dict = None,
+    job_priority: str = None,
 ):
     """
-
     :param service_account_file: relative location of service account file
     :param sql_file: relative location of sql file to read sql from
     :param timeout: job timeout parameter
@@ -271,21 +282,16 @@ def write_query_results_to_destination(
     :param destination_table: id of the destination table
     :param write_disposition: write disposition of query results
     :param sql_params: sql parameters dictionary
+    :param job_priority: priority of bigquery job, it is currently BATCH or INTERACTIVE (default)
     :return:
     """
-    if write_disposition not in WRITE_DISPOSITIONS:
-        raise ValueError(
-            "Invalid write disposition: {}. Acceptable values are WRITE_APPEND, WRITE_TRUNCATE, and WRITE_EMPTY".format(
-                write_disposition
-            )
-        )
     client = connect(service_account_file)
-    job_config = bigquery.QueryJobConfig()
-    job_config.write_disposition = write_disposition
+    job_config = get_job_config(job_priority, write_disposition)
     job_config.allow_large_results = True
     job_config.destination = get_table_ref(
         client, destination_dataset, destination_table
     )
+
     if sql_params is None:
         sql_params = dict()
     sql = read_sql(sql_file=sql_file, **sql_params)
@@ -300,6 +306,7 @@ def get_query_results(
     timeout: int = DEFAULT_TIMEOUT,
     location: str = DEFAULT_LOCATION,
     index_label: str = None,
+    job_priority: str = None,
 ):
     """
     Runs query and returns the result as dataframe
@@ -311,6 +318,7 @@ def get_query_results(
     :param timeout: query timeout duration in seconds
     :param location: query location parameter
     :param index_label: if given and return type is csv, table will be indexed with this column name
+    :param job_priority: priority of bigquery job, it is currently BATCH or INTERACTIVE (default)
     :return: query result
     """
     client = connect(service_account_file=service_account_file)
@@ -324,6 +332,7 @@ def get_query_results(
         location=location,
         return_type=return_type,
         index_label=index_label,
+        job_priority=job_priority,
     )
 
 
@@ -331,6 +340,7 @@ def get_single_value_query_results(
     service_account_file: str,
     sql_file: str,
     sql_params: dict = None,
+    job_priority: str = None,
     timeout=DEFAULT_TIMEOUT,
     location=DEFAULT_LOCATION,
 ):
@@ -340,6 +350,7 @@ def get_single_value_query_results(
     :param service_account_file: relative location of service account file
     :param sql_file: relative location of sql file to read sql from
     :param sql_params: sql parameters dictionary
+    :param job_priority: priority of bigquery job, it is currently BATCH or INTERACTIVE (default)
     :param timeout: query timeout duration in seconds
     :param location: query location parameter
     :return: query result
@@ -351,6 +362,7 @@ def get_single_value_query_results(
     return single_value_select(
         client=client,
         sql=sql,
+        job_priority=job_priority,
         timeout=timeout,
         location=location,
     )
@@ -363,6 +375,7 @@ def delete(
     table_id: str,
     where_statement_file: str,
     where_statement_params: dict = None,
+    job_priority: str = None,
     timeout=DEFAULT_TIMEOUT,
     location=DEFAULT_LOCATION,
 ):
@@ -375,11 +388,14 @@ def delete(
     :param table_id: table id
     :param where_statement_file: relative location of where statement sql file
     :param where_statement_params: parameters of where statements
+    :param job_priority: priority of bigquery job, it is currently BATCH or INTERACTIVE (default)
     :param timeout: query timeout duration in seconds
     :param location: query location parameter
     :return: query result
     """
     client = connect(service_account_file=service_account_file)
+    job_config = get_job_config(job_priority)
+
     if where_statement_params is None:
         where_statement_params = dict()
     where_statement = read_sql(sql_file=where_statement_file, **where_statement_params)
@@ -391,7 +407,7 @@ def delete(
     )
     return query(
         client=client,
-        job_config=bigquery.QueryJobConfig(),
+        job_config=job_config,
         sql=sql,
         timeout=timeout,
         location=location,
@@ -408,6 +424,7 @@ def archive(
     target_table: str,
     primary_keys: list = None,
     mode: str = "INSERT",
+    job_priority: str = None,
     timeout=DEFAULT_TIMEOUT,
     location=DEFAULT_LOCATION,
 ):
@@ -423,6 +440,7 @@ def archive(
     :param target_table: target table id
     :param primary_keys: primary key columns of the source and target tables
     :param mode: archive mode, INSERT only inserts non-existing rows and UPSERT updates and inserts
+    :param job_priority: priority of bigquery job, it is currently BATCH or INTERACTIVE (default)
     :param timeout: query timeout duration in seconds
     :param location: query location parameter
     :return:
@@ -433,6 +451,7 @@ def archive(
             + COMMA.join(i for i in ARCHIVE_MODES)
         )
     client = connect(service_account_file=service_account_file)
+
     if primary_keys is None or primary_keys == []:
         primary_keys = get_primitive_column_list(
             client, project_id, source_dataset, source_table
@@ -456,6 +475,7 @@ def archive(
             target_table=target_table,
             source_statement_params=source_statement_params,
             primary_keys=primary_keys,
+            job_priority=job_priority,
             timeout=timeout,
             location=location,
         )
@@ -468,6 +488,7 @@ def archive(
             target_table=target_table,
             source_statement_params=source_statement_params,
             primary_keys=primary_keys,
+            job_priority=job_priority,
             timeout=timeout,
             location=location,
         )
@@ -483,6 +504,7 @@ def archive(
         table_id=source_table,
         where_statement_file=ARCHIVE_DELETE_WHERE_STATEMENT_FILE,
         where_statement_params=delete_where_statement_params,
+        job_priority=job_priority,
         timeout=timeout,
         location=location,
     )
@@ -543,16 +565,14 @@ def load_to_table_from_dataframe(
     :return This instance:
     :raises: ValueError: If a usable parquet engine cannot be found. This method requires :mod:`pyarrow` to be installed
     """
-    if write_disposition not in WRITE_DISPOSITIONS:
-        raise ValueError(
-            "Invalid write disposition: {}. Acceptable values are WRITE_APPEND, WRITE_TRUNCATE, and WRITE_EMPTY".format(
-                write_disposition
-            )
-        )
     client = connect(service_account_file=service_account_file)
-    job_config = bigquery.LoadJobConfig()
+    job_config = get_job_config(
+        job_priority="",
+        write_disposition=write_disposition,
+        job_config_str="LoadJobConfig",
+    )
+
     table_ref = get_table_ref(client, dataset_id, table_name)
-    job_config.write_disposition = write_disposition
     return client.load_table_from_dataframe(
         data, table_ref, job_config=job_config
     ).result()
