@@ -25,7 +25,7 @@ def upload_file_to_s3_bucket(path_to_file: str, bucket_name: str, file_name: str
     :param bucket_name: Name of the bucket that file will be uploaded to.
     :param file_name: Name of the file (key of the file in s3).
     """
-    LOGGER.info("Upload to {bucket_name} started")
+    LOGGER.info(f"Upload to {bucket_name} started")
     upload_start = datetime.now()
     s3_client = boto3.client("s3")
     try:
