@@ -1,6 +1,7 @@
 from google.cloud import bigquery
 from datetime import datetime
 import json
+
 from airflow_commons.logger import LOGGER
 from airflow_commons.sql_resources.bigquery import (
     GET_COLUMN_NAMES_SQL_FILE,
@@ -10,7 +11,7 @@ from airflow_commons.sql_resources.bigquery import (
 from airflow_commons.utils.file_utils import read_sql
 from airflow_commons.glossary import COMMA, SQL_QUOTATION
 
-MEGABYTES_BILLED_DENOMINATOR = 2 ** 20
+MEGABYTES_BILLED_DENOMINATOR = 2**20
 AVAILABLE_COLUMN_NAMES = ["column_name", "table_name"]
 DEFAULT_TIMEOUT = 60
 DEFAULT_LOCATION = "US"
@@ -30,6 +31,13 @@ PRIMITIVE_DATA_TYPES = [
     "BIGNUMERIC",
     "STRUCT",
 ]
+JOB_PRIORITIES = ["INTERACTIVE", "BATCH"]
+WRITE_DISPOSITIONS = ["WRITE_APPEND", "WRITE_TRUNCATE", "WRITE_EMPTY"]
+
+JOB_CONFIGS = {
+    "LoadJobConfig": bigquery.LoadJobConfig(),
+    "QueryJobConfig": bigquery.QueryJobConfig(),
+}
 
 
 def connect(service_account_file: str):
@@ -106,12 +114,12 @@ def query(
     timer_end = datetime.now()
     if query_job.state == "DONE":
         LOGGER.info(
-            f"Query Job ID: {query_job.job_id}, Elapsed Time: {round((timer_end - timer_start).total_seconds())}, Total MBytes Billed: {query_job.total_bytes_billed / MEGABYTES_BILLED_DENOMINATOR}, Number of Rows Affected: {query_job.num_dml_affected_rows}"
+            f"Query Job ID: {query_job.job_id}, Elapsed Time: {round((timer_end - timer_start).total_seconds())}, Job Priority: {query_job.priority}, Total MBytes Billed: {query_job.total_bytes_billed / MEGABYTES_BILLED_DENOMINATOR}, Number of Rows Affected: {query_job.num_dml_affected_rows}"
         )
         return result
     else:
         LOGGER.error(
-            f"Query Job ID: {query_job.job_id}, Elapsed Time: {round((timer_end - timer_start).total_seconds())}"
+            f"Query Job ID: {query_job.job_id}, Job Priority: {query_job.priority}, Elapsed Time: {round((timer_end - timer_start).total_seconds())}"
         )
         raise Exception("Job is not Done.")
 
@@ -160,6 +168,7 @@ def select(
     sql: str,
     timeout: int,
     location: str,
+    job_priority: str = None,
     return_type: str = DEFAULT_RETURN_TYPE,
     index_label: str = None,
 ):
@@ -171,10 +180,12 @@ def select(
     :param sql: query sql
     :param timeout: job timeout parameter
     :param location: job location parameter
+    :param job_priority: priority of bigquery job, it is currently BATCH or INTERACTIVE (default)
     :param index_label: if given and return type is csv, table will be indexed with this column name
     :return: a dataframe of query result
     """
-    job_config = bigquery.QueryJobConfig()
+    job_config = get_job_config(job_priority)
+
     result = query(
         client=client,
         job_config=job_config,
@@ -214,6 +225,7 @@ def select(
 def single_value_select(
     client: bigquery.Client,
     sql: str,
+    job_priority: str = None,
     timeout=DEFAULT_TIMEOUT,
     location=DEFAULT_LOCATION,
 ):
@@ -223,10 +235,12 @@ def single_value_select(
     :param client: Client needed for API request
     :param sql: query sql
     :param timeout: job timeout parameter
+    :param job_priority: priority of bigquery job, it is currently BATCH or INTERACTIVE (default)
     :param location: job location parameter
     :return: requested value on first row
     """
-    job_config = bigquery.QueryJobConfig()
+    job_config = get_job_config(job_priority)
+
     result = query(
         client=client,
         job_config=job_config,
@@ -273,3 +287,32 @@ def get_primitive_column_list(
         primitive_data_types=COMMA.join('"{}"'.format(i) for i in PRIMITIVE_DATA_TYPES),
     )
     return primitive_columns_list
+
+
+def get_job_config(
+    job_priority: str,
+    write_disposition: str = None,
+    job_config_str: str = "QueryJobConfig",
+):
+    if job_config_str not in JOB_CONFIGS.keys():
+        raise ValueError(
+            "Invalid job config: {}. Acceptable values are {}".format(
+                job_config_str, JOB_CONFIGS.keys()
+            )
+        )
+
+    job_config = JOB_CONFIGS.get(job_config_str)
+
+    if hasattr(job_config, "priority"):
+        if job_priority in JOB_PRIORITIES:
+            job_config.priority = job_priority
+
+    if write_disposition is not None:
+        if write_disposition not in WRITE_DISPOSITIONS:
+            raise ValueError(
+                "Invalid write disposition: {}. Acceptable values are {}".format(
+                    write_disposition, WRITE_DISPOSITIONS
+                )
+            )
+        job_config.write_disposition = write_disposition
+    return job_config
