@@ -158,7 +158,7 @@ def get_merge_sql(
     """
     if mode not in DML_MODES:
         raise ValueError(
-            "Invalid dml mode: {}. Acceptaple modes are ".format(mode)
+            "Invalid dml mode: {}. Acceptable modes are ".format(mode)
             + COMMA.join(i for i in DML_MODES)
         )
     sql_params = get_column_list_and_update_statements(
